
import React, { useState, useEffect, useCallback, useMemo } from 'react';
import { useLocation } from 'react-router-dom';
import { Menu, Phone } from 'lucide-react';
import MobileMenu from './MobileMenu';
import LanguageSelector from './LanguageSelector';
import LanguageLink from './LanguageLink';
import { useLanguage } from '../contexts/LanguageContext';

// Debounced scroll hook
const useDebounce = (callback: () => void, delay: number) => {
  const [debounceTimer, setDebounceTimer] = useState<NodeJS.Timeout | null>(null);

  return useCallback(() => {
    if (debounceTimer) clearTimeout(debounceTimer);
    
    const timer = setTimeout(callback, delay);
    setDebounceTimer(timer);
  }, [callback, delay, debounceTimer]);
};

const Navigation = React.memo(() => {
  const location = useLocation();
  const { t } = useLanguage();
  const [isVisible, setIsVisible] = useState(true);
  const [lastScrollY, setLastScrollY] = useState(0);
  const [isMobileMenuOpen, setIsMobileMenuOpen] = useState(false);
  
  // Memoize navigation items to prevent recreation on every render
  const navItems = useMemo(() => [{
    name: t('nav.story'),
    path: '/about'
  }, {
    name: t('nav.services'),
    path: '/services'
  }, {
    name: t('nav.testimonials'),
    path: '/testimonials'
  }, {
    name: t('nav.blog'),
    path: '/blog'
  }, {
    name: t('nav.contact'),
    path: '/contact'
  }], [t]);

  // Memoize path checking function
  const isActivePath = useCallback((itemPath: string): boolean => {
    const currentPath = location.pathname;
    const pathWithoutLang = currentPath.replace(/^\/(en|nl)/, '') || '/';
    return pathWithoutLang === itemPath;
  }, [location.pathname]);
  
  // Optimized scroll handler with debouncing
  const handleScroll = useCallback(() => {
    if (typeof window !== 'undefined') {
      const currentScrollY = window.scrollY;
      if (currentScrollY > lastScrollY && currentScrollY > 100) {
        setIsVisible(false);
      } else {
        setIsVisible(true);
      }
      setLastScrollY(currentScrollY);
    }
  }, [lastScrollY]);

  const debouncedScrollHandler = useDebounce(handleScroll, 10);
  
  useEffect(() => {
    if (typeof window !== 'undefined') {
      window.addEventListener('scroll', debouncedScrollHandler, { passive: true });
      return () => {
        window.removeEventListener('scroll', debouncedScrollHandler);
      };
    }
  }, [debouncedScrollHandler]);
  
  const toggleMobileMenu = useCallback(() => {
    setIsMobileMenuOpen(prev => !prev);
  }, []);
  
  const closeMobileMenu = useCallback(() => {
    setIsMobileMenuOpen(false);
  }, []);
  
  return <>
      <nav className={`bg-white/95 backdrop-blur-sm shadow-sm border-b border-gray-100 fixed top-0 left-0 right-0 z-50 transition-transform duration-300 overflow-x-hidden max-w-full ${isVisible ? 'translate-y-0' : '-translate-y-full'}`}>
        <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8 overflow-x-hidden">
          <div className="flex justify-between items-center h-20">
            {/* Logo à gauche - Responsive sizing */}
            <LanguageLink to="/" className="flex items-center flex-shrink-0">
              <img src="/lovable-uploads/0ff8bfe1-bbe7-45a6-a6c9-876db040c935.png" alt="Lean Sigma Consult" className="h-20 sm:h-24 lg:h-28 w-auto max-w-full" />
            </LanguageLink>

            {/* Navigation Menu centré - Desktop */}
            <div className="hidden md:flex flex-1 justify-center min-w-0">
              <div className="flex items-center space-x-8">
                {navItems.map(item => <LanguageLink key={item.name} to={item.path} className={`px-3 py-2 text-sm font-medium transition-colors duration-200 whitespace-nowrap ${isActivePath(item.path) ? 'text-blue-600 border-b-2 border-blue-600' : 'text-gray-700 hover:text-blue-600'}`}>
                    {item.name}
                  </LanguageLink>)}
              </div>
            </div>

            {/* Language Selector & Phone CTA - Desktop */}
            <div className="hidden md:flex items-center space-x-6 flex-shrink-0">
              <LanguageSelector />
              <div className="flex items-center space-x-3 text-gray-700">
                <Phone className="h-5 w-5 text-blue-600 flex-shrink-0" />
                <div className="text-right">
                  <p className="text-xs text-gray-500 whitespace-nowrap">{t('nav.phone.label')}</p>
                  <p className="text-sm font-medium whitespace-nowrap">{t('nav.phone.number')}</p>
                </div>
              </div>
            </div>

            {/* Mobile menu button & Language selector */}
            <div className="md:hidden flex items-center space-x-3 flex-shrink-0">
              <LanguageSelector />
              <button onClick={toggleMobileMenu} className="p-2 rounded-lg text-gray-600 hover:text-blue-600 hover:bg-gray-100 transition-colors duration-200" aria-label="Ouvrir le menu">
                <Menu className="h-6 w-6" />
              </button>
            </div>
          </div>
        </div>
      </nav>

      {/* Mobile Menu */}
      <MobileMenu isOpen={isMobileMenuOpen} onClose={closeMobileMenu} />
    </>;
});

Navigation.displayName = 'Navigation';
export default Navigation;
